@@ -16,6 +16,7 @@ from typing import (
     Optional,
     Protocol,
     Set,
+    Tuple,
     TypedDict,
     Union,
     Literal,
@@ -33,7 +34,7 @@ from rich.rule import Rule
 from rich.syntax import Syntax
 
 from shipit.version import version as shipit_version
-from shipit.generator import generate_shipit
+from shipit.generator import generate_shipit, detect_provider
 from shipit.providers.base import CustomCommands
 from shipit.procfile import Procfile
 from dotenv import dotenv_values
@@ -88,11 +89,13 @@ class Serve:
 class Package:
     name: str
     version: Optional[str] = None
+    architecture: Optional[Literal["64-bit", "32-bit"]] = None
 
     def __str__(self) -> str:  # pragma: no cover - simple representation
+        name = f"{self.name}({self.architecture})" if self.architecture else self.name
         if self.version is None:
-            return self.name
-        return f"{self.name}@{self.version}"
+            return name
+        return f"{name}@{self.version}"
 
 
 @dataclass
@@ -780,6 +783,25 @@ class WasmerBuilder:
             "dependencies": {
                 "latest": "php/php-32@=8.3.2102",
                 "8.3": "php/php-32@=8.3.2102",
+                "8.2": "php/php-32@=8.2.2801",
+                "8.1": "php/php-32@=8.1.3201",
+                "7.4": "php/php-32@=7.4.3301",
+            },
+            "architecture_dependencies": {
+                "64-bit": {
+                    "latest": "php/php-64@=8.3.2102",
+                    "8.3": "php/php-64@=8.3.2102",
+                    "8.2": "php/php-64@=8.2.2801",
+                    "8.1": "php/php-64@=8.1.3201",
+                    "7.4": "php/php-64@=7.4.3301",
+                },
+                "32-bit": {
+                    "latest": "php/php-32@=8.3.2102",
+                    "8.3": "php/php-32@=8.3.2102",
+                    "8.2": "php/php-32@=8.2.2801",
+                    "8.1": "php/php-32@=8.1.3201",
+                    "7.4": "php/php-32@=7.4.3301",
+                },
             },
             "scripts": {"php"},
             "aliases": {},
@@ -925,13 +947,20 @@ class WasmerBuilder:
         for dep in deps:
             if dep.name in self.mapper:
                 version = dep.version or "latest"
-                if version in self.mapper[dep.name]["dependencies"]:
+                mapped_dependencies = self.mapper[dep.name]["dependencies"]
+                if dep.architecture:
+                    architecture_dependencies = (
+                        self.mapper[dep.name]
+                        .get("architecture_dependencies", {})
+                        .get(dep.architecture, {})
+                    )
+                    if architecture_dependencies:
+                        mapped_dependencies = architecture_dependencies
+                if version in mapped_dependencies:
                     console.print(
                         f"* {dep.name}@{version} mapped to {self.mapper[dep.name]['dependencies'][version]}"
                     )
-                    package_name, version = self.mapper[dep.name]["dependencies"][
-                        version
-                    ].split("@")
+                    package_name, version = mapped_dependencies[version].split("@")
                     dependencies.add(package_name, version)
                     scripts = self.mapper[dep.name].get("scripts") or []
                     for script in scripts:
@@ -1156,6 +1185,7 @@ class Ctx:
         self.mounts: List[Mount] = []
         self.volumes: List[Volume] = []
         self.services: Dict[str, Service] = {}
+        self.getenv_variables: Set[str] = set()
 
     def add_package(self, package: Package) -> str:
         index = f"{package.name}@{package.version}" if package.version else package.name
@@ -1202,10 +1232,16 @@ class Ctx:
         return f"ref:step:{len(self.steps) - 1}"
 
     def getenv(self, name: str) -> Optional[str]:
+        self.getenv_variables.add(name)
         return self.builder.getenv(name)
 
-    def dep(self, name: str, version: Optional[str] = None) -> str:
-        package = Package(name, version)
+    def dep(
+        self,
+        name: str,
+        version: Optional[str] = None,
+        architecture: Optional[Literal["64-bit", "32-bit"]] = None,
+    ) -> str:
+        package = Package(name, version, architecture)
         return self.add_package(package)
 
     def service(
@@ -1318,6 +1354,43 @@ class Ctx:
         }
 
 
+def evaluate_shipit(path: Path, builder: Builder) -> Tuple[Ctx, Serve]:
+    shipit_file = path / "Shipit"
+    if not shipit_file.exists():
+        raise FileNotFoundError(
+            f"Shipit file not found at {shipit_file}. Run `shipit generate {path}` to create it."
+        )
+    source = shipit_file.read_text()
+    ctx = Ctx(builder)
+    glb = sl.Globals.standard()
+    mod = sl.Module()
+
+    mod.add_callable("service", ctx.service)
+    mod.add_callable("getenv", ctx.getenv)
+    mod.add_callable("dep", ctx.dep)
+    mod.add_callable("serve", ctx.serve)
+    mod.add_callable("run", ctx.run)
+    mod.add_callable("mount", ctx.mount)
+    mod.add_callable("volume", ctx.volume)
+    mod.add_callable("workdir", ctx.workdir)
+    mod.add_callable("copy", ctx.copy)
+    mod.add_callable("path", ctx.path)
+    mod.add_callable("env", ctx.env)
+    mod.add_callable("use", ctx.use)
+
+    dialect = sl.Dialect.extended()
+    dialect.enable_f_strings = True
+
+    ast = sl.parse("shipit", source, dialect=dialect)
+
+    sl.eval(mod, ast, glb)
+    if not ctx.serves:
+        raise ValueError(f"No serve definition found in {shipit_file}")
+    assert len(ctx.serves) <= 1, "Only one serve is allowed for now"
+    serve = next(iter(ctx.serves.values()))
+    return ctx, serve
+
+
 def print_help() -> None:
     panel = Panel(
         f"Shipit {shipit_version}",
@@ -1528,7 +1601,8 @@ def generate(
     context_settings={"allow_extra_args": True, "ignore_unknown_options": True},
 )
 def _default(ctx: typer.Context) -> None:
-    print_help()
+    if ctx.invoked_subcommand is None:
+        print_help()
 
 
 @app.command(name="deploy")
@@ -1612,6 +1686,103 @@ def serve(
             raise Exception("Wasmer deploy is only supported for Wasmer builders")
 
 
+@app.command(name="plan")
+def plan(
+    path: Path = typer.Argument(
+        Path("."),
+        help="Project path (defaults to current directory).",
+        show_default=False,
+    ),
+    wasmer: bool = typer.Option(
+        False,
+        help="Use Wasmer to evaluate the project.",
+    ),
+    wasmer_bin: Optional[Path] = typer.Option(
+        None,
+        help="The path to the Wasmer binary.",
+    ),
+    wasmer_registry: Optional[str] = typer.Option(
+        None,
+        help="Wasmer registry.",
+    ),
+    wasmer_token: Optional[str] = typer.Option(
+        None,
+        help="Wasmer token.",
+    ),
+    docker: bool = typer.Option(
+        False,
+        help="Use Docker to evaluate the project.",
+    ),
+    docker_client: Optional[str] = typer.Option(
+        None,
+        help="Use a specific Docker client (such as depot, podman, etc.)",
+    ),
+) -> None:
+    if not path.exists():
+        raise Exception(f"The path {path} does not exist")
+
+    custom_commands = CustomCommands()
+    procfile_path = path / "Procfile"
+    if procfile_path.exists():
+        try:
+            procfile = Procfile.loads(procfile_path.read_text())
+            custom_commands.start = procfile.get_start_command()
+        except Exception:
+            pass
+
+    builder: Builder
+    if docker or docker_client:
+        builder = DockerBuilder(path, docker_client)
+    else:
+        builder = LocalBuilder(path)
+    if wasmer:
+        builder = WasmerBuilder(
+            builder, path, registry=wasmer_registry, token=wasmer_token, bin=wasmer_bin
+        )
+
+    ctx, serve = evaluate_shipit(path, builder)
+    metadata_commands: Dict[str, Optional[str]] = {
+        "start": serve.commands.get("start"),
+        "after_deploy": serve.commands.get("after_deploy"),
+    }
+
+    def _collect_group_commands(group: str) -> Optional[str]:
+        commands = [
+            step.command
+            for step in serve.build
+            if isinstance(step, RunStep) and step.group == group
+        ]
+        if not commands:
+            return None
+        return " && ".join(commands)
+
+    metadata_install = _collect_group_commands("install")
+    metadata_build = _collect_group_commands("build")
+    metadata_commands["install"] = metadata_install
+    metadata_commands["build"] = metadata_build
+    platform: Optional[str]
+    try:
+        provider_cls = detect_provider(path, custom_commands)
+        provider_instance = provider_cls(path, custom_commands)
+        provider_instance.initialize()
+        platform = provider_instance.platform()
+    except Exception:
+        platform = None
+    plan_output = {
+        "provider": serve.provider,
+        "metadata": {
+            "platform": platform,
+            "commands": metadata_commands,
+        },
+        "config": sorted(ctx.getenv_variables),
+        "services": [
+            {"name": svc.name, "provider": svc.provider}
+            for svc in (serve.services or [])
+        ],
+    }
+    print(json.dumps(plan_output, indent=4))
+
+
 @app.command(name="build")
 def build(
     path: Path = typer.Argument(
@@ -1659,12 +1830,6 @@ def build(
     if not path.exists():
         raise Exception(f"The path {path} does not exist")
 
-    ab_file = path / "Shipit"
-    if not ab_file.exists():
-        raise FileNotFoundError(
-            f"Shipit file not found at {ab_file}. Run `shipit generate {path}` to create it."
-        )
-    source = open(ab_file).read()
     builder: Builder
     if docker or docker_client:
         builder = DockerBuilder(path, docker_client)
@@ -1675,30 +1840,7 @@ def build(
             builder, path, registry=wasmer_registry, token=wasmer_token, bin=wasmer_bin
         )
 
-    ctx = Ctx(builder)
-    glb = sl.Globals.standard()
-    mod = sl.Module()
-
-    mod.add_callable("service", ctx.service)
-    mod.add_callable("getenv", ctx.getenv)
-    mod.add_callable("dep", ctx.dep)
-    mod.add_callable("serve", ctx.serve)
-    mod.add_callable("run", ctx.run)
-    mod.add_callable("mount", ctx.mount)
-    mod.add_callable("volume", ctx.volume)
-    mod.add_callable("workdir", ctx.workdir)
-    mod.add_callable("copy", ctx.copy)
-    mod.add_callable("path", ctx.path)
-    mod.add_callable("env", ctx.env)
-    mod.add_callable("use", ctx.use)
-
-    dialect = sl.Dialect.extended()
-    dialect.enable_f_strings = True
-
-    ast = sl.parse("shipit", source, dialect=dialect)
-
-    sl.eval(mod, ast, glb)
-    assert len(ctx.serves) <= 1, "Only one serve is allowed for now"
+    ctx, serve = evaluate_shipit(path, builder)
     env = {
         "PATH": "",
         "COLORTERM": os.environ.get("COLORTERM", ""),
@@ -1706,7 +1848,6 @@ def build(
         "LS_COLORS": os.environ.get("LS_COLORS", "0"),
         "CLICOLOR": os.environ.get("CLICOLOR", "0"),
     }
-    serve = next(iter(ctx.serves.values()))
 
     if skip_docker_if_safe_build and serve.build and len(serve.build) > 0:
         # If it doesn't have a run step, then it's safe to skip Docker and run all the
